import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { useDataMap } from './useDataMap';
import { useDataViews } from './useDataViews';
import { Marks } from './Marks';
import { tsv, scaleLinear, extent } from 'd3';

const width = 960;
const height = 500;

const App = () => {
  const mapData = useDataMap();
  const viewData = useDataViews();
  
  if (!mapData) {
    return <pre>Loading...</pre>;
  }
  
  if (!viewData) {
    return <pre>Loading...</pre>;
  }
  
  const longitude = d => d.longitude;
  const latitude = d => d.latitude;
  const name = d => d.name;
  
  const longScale = scaleLinear()
  	.domain(extent(viewData, longitude))
  	.range([0, width])
  
  const latScale = scaleLinear()
  	.domain(extent(viewData, latitude))
  	.range([height, 0])

  return (
		<svg width={width} height={height}>
      <Marks 
        mapData={mapData}
        viewData={viewData}
        longitude={longitude} 
        latitude={latitude} 
        longScale={longScale}
        latScale={latScale}
        name={name}/>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
